<?php

namespace Drupal\termly\Form;

use Drupal\Core\Cache\CacheTagsInvalidatorInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure termly settings for this site.
 */
class TermlyAdminSettingsForm extends ConfigFormBase {

  /**
   * The cache tags invalidator service.
   *
   * @var \Drupal\Core\Cache\CacheTagsInvalidatorInterface
   */
  protected $cacheTagsInvalidator;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory, TypedConfigManagerInterface $typedConfigManager, CacheTagsInvalidatorInterface $cache_tags_invalidator) {
    parent::__construct($config_factory, $typedConfigManager);

    $this->cacheTagsInvalidator = $cache_tags_invalidator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('cache_tags.invalidator'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'termly_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['termly.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('termly.settings');

    $form['enabled'] = [
      '#default_value' => $config->get('enabled'),
      '#description' => $this->t('Check this box to enable Termly on your site.'),
      '#title' => $this->t('Termly Enabled'),
      '#type' => 'checkbox',
    ];

    $form['site_key'] = [
      '#default_value' => $config->get('site_key'),
      '#description' => $this->t('The UUID component of the URL provided to you. It follows this pattern:<br>XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX'),
      '#maxlength' => 50,
      '#required' => TRUE,
      '#title' => $this->t('Site key'),
      '#type' => 'textfield',
    ];

    $form['base_url'] = [
      '#default_value' => $config->get('base_url'),
      '#description' => $this->t("The base URL of the URL provided to you. It's likely<br>https://app.termly.io/resource-blocker/"),
      '#maxlength' => 50,
      '#required' => TRUE,
      '#title' => $this->t('Base URL'),
      '#type' => 'textfield',
    ];

    $form['auto_block'] = [
      '#default_value' => $config->get('auto_block'),
      '#description' => $this->t("Termly's Auto Blocker will automatically block scripts and other objects on your site from setting cookies and tracking visitors without their consent. <a href=\":url\" target=\"_blank\">Learn more about Auto Blocker</a>.", [
        ':url' => 'https://help.termly.io/support/solutions/articles/69000252637-auto-blocker-implementation-guide',
      ]),
      '#title' => $this->t('Enable Auto Blocker'),
      '#type' => 'checkbox',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->cacheTagsInvalidator->invalidateTags(['library_info']);

    $config = $this->config('termly.settings');
    $config
      ->set('site_key', $form_state->getValue('site_key'))
      ->set('base_url', $form_state->getValue('base_url'))
      ->set('auto_block', $form_state->getValue('auto_block'))
      ->set('enabled', $form_state->getValue('enabled'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
